@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # __init__.py
 
 """
@@ -21,7 +22,7 @@ import warnings
     # importlib.reload(kececinumbers) # F821 undefined name 'kececinumbers'
 
 # Paket sürüm numarası
-__version__ = "0.4.2"
+__version__ = "0.5.9"
 __author__ = "Mehmet Keçeci"
 __email__ = "mkececi@yaani.com"
 
@@ -38,6 +39,9 @@ __all__ = [
     'get_with_params',
     'get_interactive',
     'get_random_type',
+    '_get_integer_representation',
+    '_parse_quaternion_from_csv',
+    'generate_kececi_vectorial',
 
     # --- Core Generation and Analysis ---
     'unified_generator',
@@ -82,6 +86,9 @@ try:
         get_with_params,
         get_interactive,
         get_random_type,
+        _get_integer_representation,
+        _parse_quaternion_from_csv,
+        generate_kececi_vectorial,
         unified_generator,
         is_prime,
         find_period,
