@@ -482,93 +482,147 @@ def get_random_type(num_iterations: int, fixed_start_raw: str = "0", fixed_add_b
         add_value_base_scalar=fixed_add_base_scalar
     )
 
+def generate_kececi_vectorial(q0_str, c_str, u_str, iterations):
+    """
+    Keçeci Haritası'nı tam vektörel toplama ile üreten geliştirilmiş fonksiyon.
+    Bu, kütüphanenin ana üretim fonksiyonu olabilir.
+    Tüm girdileri metin (string) olarak alarak esneklik sağlar.
+    """
+    try:
+        # Girdi metinlerini kuaterniyon nesnelerine dönüştür
+        w, x, y, z = map(float, q0_str.split(','))
+        q0 = np.quaternion(w, x, y, z)
+        
+        cw, cx, cy, cz = map(float, c_str.split(','))
+        c = np.quaternion(cw, cx, cy, cz)
+
+        uw, ux, uy, uz = map(float, u_str.split(','))
+        u = np.quaternion(uw, ux, uy, uz)
+
+    except (ValueError, IndexError):
+        raise ValueError("Girdi metinleri 'w,x,y,z' formatında olmalıdır.")
+
+    trajectory = [q0]
+    prime_events = []
+    current_q = q0
+
+    for i in range(iterations):
+        y = current_q + c
+        processing_val = y
+
+        while True:
+            scalar_int = int(processing_val.w)
+
+            if scalar_int % 2 == 0:
+                next_q = processing_val / 2.0
+                break
+            elif scalar_int % 3 == 0:
+                next_q = processing_val / 3.0
+                break
+            elif is_prime(scalar_int):
+                if processing_val == y:
+                    prime_events.append((i, scalar_int))
+                processing_val += u
+                continue
+            else:
+                next_q = processing_val
+                break
+        
+        trajectory.append(next_q)
+        current_q = next_q
+        
+    return trajectory, prime_events
+
+def _parse_quaternion_from_csv(s: str) -> np.quaternion:
+    """Parses a comma-separated string 'w,x,y,z' into a quaternion."""
+    try:
+        parts = [float(p.strip()) for p in s.split(',')]
+        if len(parts) != 4:
+            raise ValueError("Girdi 4 bileşen içermelidir.")
+        # *parts -> (parts[0], parts[1], parts[2], parts[3])
+        return np.quaternion(*parts)
+    except (ValueError, IndexError) as e:
+        raise ValueError(f"Geçersiz virgülle ayrılmış kuaterniyon formatı: '{s}'.") from e
+
 # ==============================================================================
 # --- CORE GENERATOR ---
 # ==============================================================================
 
-def unified_generator(kececi_type: int, start_input_raw: str, add_input_base_scalar: float, iterations: int) -> List[Any]:
-    """Core engine to generate Keçeci Number sequences."""
-    current_value = None
-    add_value_typed = None
-    ask_unit = None
+def unified_generator(kececi_type: int, start_input_raw: str, add_input_raw: str, iterations: int, include_intermediate_steps: bool = False) -> List[Any]:
+    """
+    Core engine to generate Keçeci Number sequences.
+
+    Bu nihai versiyon, tüm sayı tipleri için esnek girdi işleme, kuaterniyonlar
+    için tam vektörel toplama desteği sunar ve isteğe bağlı olarak ara
+    hesaplama adımlarını da, veri tekrarı olmadan doğru bir şekilde döndürür.
+
+    Args:
+        kececi_type (int): Keçeci Sayı türü (1-11).
+        start_input_raw (str): Başlangıç değerini temsil eden metin.
+        add_input_raw (str): Her adımda eklenecek sabiti temsil eden metin.
+        iterations (int): Üretilecek Keçeci adımı sayısı.
+        include_intermediate_steps (bool, optional): True ise, ara hesaplama
+            değerlerini de son listeye ekler. Varsayılan: False.
+
+    Returns:
+        List[Any]: Oluşturulan Keçeci Sayıları dizisi.
+    """
+    
+    if not (TYPE_POSITIVE_REAL <= kececi_type <= TYPE_NEUTROSOPHIC_BICOMPLEX):
+        raise ValueError(f"Invalid Keçeci Number Type: {kececi_type}. Must be between {TYPE_POSITIVE_REAL} and {TYPE_NEUTROSOPHIC_BICOMPLEX}.")
+
+    # --- 1. Değişkenlerin Başlatılması ---
+    # Varsayılan bölme türünü ondalıklı olarak ayarla.
+    # Tamsayı tipleri (POSITIVE/NEGATIVE_REAL) bu değeri kendi blokları içinde ezecektir.
     use_integer_division = False
-
+    
     try:
-        a_float = float(add_input_base_scalar)
-
+        # Her sayı tipi, kendi `elif` bloğu içinde kendi girdisini işler.
         if kececi_type in [TYPE_POSITIVE_REAL, TYPE_NEGATIVE_REAL]:
-            current_value = int(float(start_input_raw))
-            add_value_typed = int(a_float)
-            ask_unit = 1
-            use_integer_division = True
+            current_value = int(float(start_input_raw)); add_value_typed = int(float(add_input_raw)); ask_unit = 1; use_integer_division = True
         elif kececi_type == TYPE_FLOAT:
-            current_value = float(start_input_raw)
-            add_value_typed = a_float
-            ask_unit = 1.0
+            current_value = float(start_input_raw); add_value_typed = float(add_input_raw); ask_unit = 1.0
         elif kececi_type == TYPE_RATIONAL:
-            current_value = Fraction(start_input_raw)
-            add_value_typed = Fraction(add_input_base_scalar)
-            ask_unit = Fraction(1)
+            current_value = Fraction(start_input_raw); add_value_typed = Fraction(add_input_raw); ask_unit = Fraction(1)
         elif kececi_type == TYPE_COMPLEX:
-            current_value = _parse_complex(start_input_raw)
-            add_value_typed = complex(a_float, a_float)
-            ask_unit = 1 + 1j
-        elif kececi_type == TYPE_NEUTROSOPHIC:
-            a, b = _parse_neutrosophic(start_input_raw)
-            current_value = NeutrosophicNumber(a, b)
-            add_value_typed = NeutrosophicNumber(a_float, 0)
-            ask_unit = NeutrosophicNumber(1, 1)
-        elif kececi_type == TYPE_NEUTROSOPHIC_COMPLEX:
-            s_complex = _parse_complex(start_input_raw)
-            current_value = NeutrosophicComplexNumber(s_complex.real, s_complex.imag, 0.0)
-            add_value_typed = NeutrosophicComplexNumber(a_float, 0.0, 0.0)
-            ask_unit = NeutrosophicComplexNumber(1, 1, 1)
-        elif kececi_type == TYPE_HYPERREAL:
-            a, b = _parse_hyperreal(start_input_raw)
-            sequence_list = [a + b / n for n in range(1, 11)]
-            current_value = HyperrealNumber(sequence_list)
-            add_sequence = [a_float] + [0.0] * 9
-            add_value_typed = HyperrealNumber(add_sequence)
-            ask_unit = HyperrealNumber([1.0] * 10)
-        elif kececi_type == TYPE_BICOMPLEX:
-            s_complex = _parse_complex(start_input_raw)
-            a_complex = complex(a_float)
-            current_value = BicomplexNumber(s_complex, s_complex / 2)
-            add_value_typed = BicomplexNumber(a_complex, a_complex / 2)
-            ask_unit = BicomplexNumber(complex(1, 1), complex(0.5, 0.5))
-        elif kececi_type == TYPE_NEUTROSOPHIC_BICOMPLEX:
-            s_complex = _parse_complex(start_input_raw)
-            current_value = NeutrosophicBicomplexNumber(s_complex.real, s_complex.imag, 0, 0, 0, 0, 0, 0)
-            add_value_typed = NeutrosophicBicomplexNumber(a_float, 0, 0, 0, 0, 0, 0, 0)
-            ask_unit = NeutrosophicBicomplexNumber(*([1.0] * 8))
+            current_value = _parse_complex(start_input_raw); a_float = float(add_input_raw); add_value_typed = complex(a_float, a_float); ask_unit = 1 + 1j
         elif kececi_type == TYPE_QUATERNION:
-            current_value = _parse_quaternion(start_input_raw)
-            add_value_typed = np.quaternion(a_float, a_float, a_float, a_float)
-            ask_unit = np.quaternion(1, 1, 1, 1)
-        else:
-            raise ValueError(f"Invalid Keçeci Number Type: {kececi_type}")
-
+            current_value = _parse_quaternion_from_csv(start_input_raw); add_value_typed = _parse_quaternion_from_csv(add_input_raw); ask_unit = np.quaternion(1, 1, 1, 1)
+        elif kececi_type == TYPE_NEUTROSOPHIC:
+            a, b = _parse_neutrosophic(start_input_raw); current_value = NeutrosophicNumber(a, b); a_float = float(add_input_raw); add_value_typed = NeutrosophicNumber(a_float, 0); ask_unit = NeutrosophicNumber(1, 1)
+        elif kececi_type == TYPE_NEUTROSOPHIC_COMPLEX:
+            s_complex = _parse_complex(start_input_raw); current_value = NeutrosophicComplexNumber(s_complex.real, s_complex.imag, 0.0); a_float = float(add_input_raw); add_value_typed = NeutrosophicComplexNumber(a_float, 0.0, 0.0); ask_unit = NeutrosophicComplexNumber(1, 1, 1)
+        elif kececi_type == TYPE_HYPERREAL:
+            a, b = _parse_hyperreal(start_input_raw); sequence_list = [a + b / n for n in range(1, 11)]; current_value = HyperrealNumber(sequence_list); a_float = float(add_input_raw); add_sequence = [a_float] + [0.0] * 9; add_value_typed = HyperrealNumber(add_sequence); ask_unit = HyperrealNumber([1.0] * 10)
+        elif kececi_type == TYPE_BICOMPLEX:
+            s_complex = _parse_complex(start_input_raw); a_float = float(add_input_raw); a_complex = complex(a_float); current_value = BicomplexNumber(s_complex, s_complex / 2); add_value_typed = BicomplexNumber(a_complex, a_complex / 2); ask_unit = BicomplexNumber(complex(1, 1), complex(0.5, 0.5))
+        elif kececi_type == TYPE_NEUTROSOPHIC_BICOMPLEX:
+            s_complex = _parse_complex(start_input_raw); current_value = NeutrosophicBicomplexNumber(s_complex.real, s_complex.imag, 0, 0, 0, 0, 0, 0); a_float = float(add_input_raw); add_value_typed = NeutrosophicBicomplexNumber(a_float, 0, 0, 0, 0, 0, 0, 0); ask_unit = NeutrosophicBicomplexNumber(*([1.0] * 8))
     except (ValueError, TypeError) as e:
-        print(f"ERROR: Failed to initialize type {kececi_type} with input '{start_input_raw}': {e}")
+        print(f"ERROR: Failed to initialize type {kececi_type} with start='{start_input_raw}' and increment='{add_input_raw}': {e}")
         return []
 
-    sequence = [current_value]
+    # --- 2. Üreteç Döngüsü ---
+    clean_trajectory = [current_value]
+    full_log = [current_value]
+    
     last_divisor_used = None
     ask_counter = 0
     
     for _ in range(iterations):
+        # --- Bir Sonraki Adımın Değerini (next_q) Hesapla ---
         added_value = current_value + add_value_typed
-        sequence.append(added_value)
         
-        result_value = added_value
+        next_q = added_value
         divided_successfully = False
+        modified_value = None
 
         primary_divisor = 3 if last_divisor_used == 2 or last_divisor_used is None else 2
         alternative_divisor = 2 if primary_divisor == 3 else 3
         
         for divisor in [primary_divisor, alternative_divisor]:
             if _is_divisible(added_value, divisor, kececi_type):
-                result_value = added_value // divisor if use_integer_division else added_value / divisor
+                next_q = added_value // divisor if use_integer_division else added_value / divisor
                 last_divisor_used = divisor
                 divided_successfully = True
                 break
@@ -576,20 +630,35 @@ def unified_generator(kececi_type: int, start_input_raw: str, add_input_base_sca
         if not divided_successfully and is_prime(added_value):
             modified_value = (added_value + ask_unit) if ask_counter == 0 else (added_value - ask_unit)
             ask_counter = 1 - ask_counter
-            sequence.append(modified_value)
             
-            result_value = modified_value 
+            next_q = modified_value 
             
             for divisor in [primary_divisor, alternative_divisor]:
                 if _is_divisible(modified_value, divisor, kececi_type):
-                    result_value = modified_value // divisor if use_integer_division else modified_value / divisor
+                    next_q = modified_value // divisor if use_integer_division else modified_value / divisor
                     last_divisor_used = divisor
                     break
         
-        sequence.append(result_value)
-        current_value = result_value
+        # --- Sonuçları Ayrı ve Doğru Listelere Kaydet ---
+        full_log.append(added_value)
+        if modified_value is not None:
+            full_log.append(modified_value)
         
-    return sequence
+        # Nihai sonucu, eğer bir önceki ara adımdan farklıysa log'a ekle.
+        # Bu, `(12.3, ...), (12.3, ...)` tekrarını önler.
+        if not full_log or next_q != full_log[-1]:
+             full_log.append(next_q)
+        
+        clean_trajectory.append(next_q)
+        
+        # --- Durumu Güncelle ---
+        current_value = next_q
+        
+    # --- 3. İsteğe Göre Doğru Listeyi Döndür ---
+    if include_intermediate_steps:
+        return full_log
+    else:
+        return clean_trajectory
 
 def print_detailed_report(sequence: List[Any], params: Dict[str, Any]):
     """Generates and prints a detailed report of the sequence results."""
@@ -641,13 +710,20 @@ def print_detailed_report(sequence: List[Any], params: Dict[str, Any]):
 # --- HIGH-LEVEL CONTROL FUNCTIONS ---
 # ==============================================================================
 
-def get_with_params(kececi_type_choice: int, iterations: int, start_value_raw: str = "0", add_value_base_scalar: float = 9.0) -> List[Any]:
-    """Generates Keçeci Numbers with specified parameters."""
+def get_with_params(kececi_type_choice: int, iterations: int, start_value_raw: str, add_value_raw: str, include_intermediate_steps: bool = False) -> List[Any]:
+    """Generates Keçeci Numbers with specified parameters, supporting full vectorial addition."""
     print(f"\n--- Generating Sequence: Type {kececi_type_choice}, Steps {iterations} ---")
-    print(f"Start: '{start_value_raw}', Increment: {add_value_base_scalar}")
+    print(f"Start: '{start_value_raw}', Increment: '{add_value_raw}'")
+    if include_intermediate_steps:
+        print("Mode: Detailed (including intermediate steps)")
 
     generated_sequence = unified_generator(
-        kececi_type_choice, start_value_raw, add_value_base_scalar, iterations
+        kececi_type_choice, 
+        start_value_raw, 
+        add_value_raw, 
+        iterations,
+        # Yeni parametreyi aktar
+        include_intermediate_steps=include_intermediate_steps 
     )
     
     if generated_sequence:
@@ -663,47 +739,66 @@ def get_with_params(kececi_type_choice: int, iterations: int, start_value_raw: s
     return generated_sequence
 
 def get_interactive() -> Tuple[List[Any], Dict[str, Any]]:
-    """Interactively gets parameters from the user to generate a sequence."""
-    print("\n--- Keçeci Number Interactive Generator ---")
+    """
+    Interactively gets parameters from the user to generate a Keçeci Numbers sequence.
+    This version is improved for code clarity and compatibility with the module's
+    current interface.
+    """
+    print("\n--- Keçeci Numbers Interactive Generator ---")
     print("  1: Positive Real    2: Negative Real     3: Complex")
     print("  4: Float            5: Rational          6: Quaternion")
     print("  7: Neutrosophic     8: Neutro-Complex   9: Hyperreal")
     print(" 10: Bicomplex        11: Neutro-Bicomplex")
     
+    # Get a valid number type from the user
     while True:
         try:
-            type_choice = int(input("Select Keçeci Number Type (1-11): "))
+            type_choice = int(input("Select a Keçeci Number Type (1-11): "))
             if 1 <= type_choice <= 11:
                 break
             print("Invalid type. Please enter a number between 1 and 11.")
         except ValueError:
             print("Invalid input. Please enter a number.")
         
-    prompts = {
+    # User prompts for the starting value
+    start_prompts = {
         1: "Enter positive integer start (e.g., '10'): ",
         2: "Enter negative integer start (e.g., '-5'): ",
-        3: "Enter complex start (e.g., '3+4j' or '3' for 3+3j): ",
+        3: "Enter complex start (e.g., '3+4j'): ",
         4: "Enter float start (e.g., '3.14'): ",
-        5: "Enter rational start (e.g., '7/2' or '5'): ",
-        6: "Enter quaternion (e.g., '1+2i-3j+k' or '2.5'): ",
-        7: "Enter neutrosophic start (e.g., '5+2I' or '7'): ",
+        5: "Enter rational start (e.g., '7/2'): ",
+        6: "Enter quaternion start (in 'w,x,y,z' format, e.g., '1.0,2.0,-3.0,1.0'): ",
+        7: "Enter neutrosophic start (e.g., '5+2I'): ",
         8: "Enter complex base for neutro-complex (e.g., '1-2j'): ",
-        9: "Enter hyperreal start (e.g., '5+3e' or '10'): ",
+        9: "Enter hyperreal start (e.g., '5+3e'): ",
         10: "Enter complex base for bicomplex (e.g., '2+1j'): ",
         11: "Enter complex base for neutro-bicomplex (e.g., '1+2j'): "
     }
     
-    start_prompt = prompts.get(type_choice, "Enter starting value: ")
-    start_input_val_raw = input(start_prompt)
-    add_base_scalar_val = float(input("Enter base scalar increment (e.g., 9.0): "))
+    # User prompts for the increment value
+    add_prompts = {
+        TYPE_QUATERNION: "Enter quaternion increment (in 'w,x,y,z' format, e.g., '1.3,-2.1,0.5,3.4'): "
+    }
+    default_add_prompt = "Enter increment value (e.g., '9.0'): "
+    
+    # Get inputs from the user
+    start_input_val_raw = input(start_prompts.get(type_choice, "Enter starting value: "))
+    add_input_val_raw = input(add_prompts.get(type_choice, default_add_prompt))
     num_kececi_steps = int(input("Enter number of Keçeci steps (e.g., 15): "))
     
-    sequence = get_with_params(type_choice, num_kececi_steps, start_input_val_raw, add_base_scalar_val)
+    # Generate the sequence with the correct parameter names and values
+    sequence = get_with_params(
+        kececi_type_choice=type_choice,
+        iterations=num_kececi_steps,
+        start_value_raw=start_input_val_raw,
+        add_value_raw=add_input_val_raw
+    )
     
+    # Gather the parameters in a dictionary to return
     params = {
         "type_choice": type_choice,
         "start_val": start_input_val_raw,
-        "add_val": add_base_scalar_val,
+        "add_val": add_input_val_raw,
         "steps": num_kececi_steps
     }
     return sequence, params
